# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BulkIdErrorReason(str, Enum):
    """
    BulkIdErrorReason
    """

    """
    allowed enum values
    """
    DUPLICATE = "duplicate"
    NO_PERMISSION = "no_permission"
    NOT_FOUND = "not_found"
    UNKNOWN = "unknown"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BulkIdErrorReason from a JSON string"""
        return cls(json.loads(json_str))
