# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self


class ServerConfigDto(BaseModel):
    """
    ServerConfigDto
    """  # noqa: E501

    external_domain: StrictStr = Field(alias="externalDomain")
    is_initialized: StrictBool = Field(alias="isInitialized")
    is_onboarded: StrictBool = Field(alias="isOnboarded")
    login_page_message: StrictStr = Field(alias="loginPageMessage")
    maintenance_mode: StrictBool = Field(alias="maintenanceMode")
    map_dark_style_url: StrictStr = Field(alias="mapDarkStyleUrl")
    map_light_style_url: StrictStr = Field(alias="mapLightStyleUrl")
    oauth_button_text: StrictStr = Field(alias="oauthButtonText")
    public_users: StrictBool = Field(alias="publicUsers")
    trash_days: StrictInt = Field(alias="trashDays")
    user_delete_delay: StrictInt = Field(alias="userDeleteDelay")
    __properties: ClassVar[List[str]] = [
        "externalDomain",
        "isInitialized",
        "isOnboarded",
        "loginPageMessage",
        "maintenanceMode",
        "mapDarkStyleUrl",
        "mapLightStyleUrl",
        "oauthButtonText",
        "publicUsers",
        "trashDays",
        "userDeleteDelay",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServerConfigDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServerConfigDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "externalDomain": obj.get("externalDomain"),
                "isInitialized": obj.get("isInitialized"),
                "isOnboarded": obj.get("isOnboarded"),
                "loginPageMessage": obj.get("loginPageMessage"),
                "maintenanceMode": obj.get("maintenanceMode"),
                "mapDarkStyleUrl": obj.get("mapDarkStyleUrl"),
                "mapLightStyleUrl": obj.get("mapLightStyleUrl"),
                "oauthButtonText": obj.get("oauthButtonText"),
                "publicUsers": obj.get("publicUsers"),
                "trashDays": obj.get("trashDays"),
                "userDeleteDelay": obj.get("userDeleteDelay"),
            }
        )
        return _obj
