# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List
from immich.client.models.usage_by_user_dto import UsageByUserDto
from typing import Optional, Set
from typing_extensions import Self


class ServerStatsResponseDto(BaseModel):
    """
    ServerStatsResponseDto
    """  # noqa: E501

    photos: StrictInt
    usage: StrictInt
    usage_by_user: List[UsageByUserDto] = Field(alias="usageByUser")
    usage_photos: StrictInt = Field(alias="usagePhotos")
    usage_videos: StrictInt = Field(alias="usageVideos")
    videos: StrictInt
    __properties: ClassVar[List[str]] = [
        "photos",
        "usage",
        "usageByUser",
        "usagePhotos",
        "usageVideos",
        "videos",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServerStatsResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in usage_by_user (list)
        _items = []
        if self.usage_by_user:
            for _item_usage_by_user in self.usage_by_user:
                if _item_usage_by_user:
                    _items.append(_item_usage_by_user.to_dict())
            _dict["usageByUser"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServerStatsResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "photos": obj.get("photos") if obj.get("photos") is not None else 0,
                "usage": obj.get("usage") if obj.get("usage") is not None else 0,
                "usageByUser": [
                    UsageByUserDto.from_dict(_item) for _item in obj["usageByUser"]
                ]
                if obj.get("usageByUser") is not None
                else None,
                "usagePhotos": obj.get("usagePhotos")
                if obj.get("usagePhotos") is not None
                else 0,
                "usageVideos": obj.get("usageVideos")
                if obj.get("usageVideos") is not None
                else 0,
                "videos": obj.get("videos") if obj.get("videos") is not None else 0,
            }
        )
        return _obj
