# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OAuthTokenEndpointAuthMethod(str, Enum):
    """
    OAuthTokenEndpointAuthMethod
    """

    """
    allowed enum values
    """
    CLIENT_SECRET_POST = "client_secret_post"
    CLIENT_SECRET_BASIC = "client_secret_basic"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OAuthTokenEndpointAuthMethod from a JSON string"""
        return cls(json.loads(json_str))
