# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.plugin_trigger_type import PluginTriggerType
from immich.client.models.workflow_action_item_dto import WorkflowActionItemDto
from immich.client.models.workflow_filter_item_dto import WorkflowFilterItemDto
from typing import Set
from typing_extensions import Self


class WorkflowCreateDto(BaseModel):
    """
    WorkflowCreateDto
    """  # noqa: E501

    actions: List[WorkflowActionItemDto]
    description: Optional[StrictStr] = None
    enabled: Optional[StrictBool] = None
    filters: List[WorkflowFilterItemDto]
    name: StrictStr
    trigger_type: PluginTriggerType = Field(alias="triggerType")
    __properties: ClassVar[List[str]] = [
        "actions",
        "description",
        "enabled",
        "filters",
        "name",
        "triggerType",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WorkflowCreateDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item_actions in self.actions:
                if _item_actions:
                    _items.append(_item_actions.to_dict())
            _dict["actions"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in filters (list)
        _items = []
        if self.filters:
            for _item_filters in self.filters:
                if _item_filters:
                    _items.append(_item_filters.to_dict())
            _dict["filters"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WorkflowCreateDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "actions": [
                    WorkflowActionItemDto.from_dict(_item) for _item in obj["actions"]
                ]
                if obj.get("actions") is not None
                else None,
                "description": obj.get("description"),
                "enabled": obj.get("enabled"),
                "filters": [
                    WorkflowFilterItemDto.from_dict(_item) for _item in obj["filters"]
                ]
                if obj.get("filters") is not None
                else None,
                "name": obj.get("name"),
                "triggerType": obj.get("triggerType"),
            }
        )
        return _obj
