# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchSuggestionType(str, Enum):
    """
    SearchSuggestionType
    """

    """
    allowed enum values
    """
    COUNTRY = "country"
    STATE = "state"
    CITY = "city"
    CAMERA_MINUS_MAKE = "camera-make"
    CAMERA_MINUS_MODEL = "camera-model"
    CAMERA_MINUS_LENS_MINUS_MODEL = "camera-lens-model"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchSuggestionType from a JSON string"""
        return cls(json.loads(json_str))
