# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.memory_type import MemoryType
from typing import Set
from typing_extensions import Self


class SyncMemoryV1(BaseModel):
    """
    SyncMemoryV1
    """  # noqa: E501

    created_at: datetime = Field(alias="createdAt")
    data: Dict[str, Any]
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    hide_at: Optional[datetime] = Field(alias="hideAt")
    id: StrictStr
    is_saved: StrictBool = Field(alias="isSaved")
    memory_at: datetime = Field(alias="memoryAt")
    owner_id: StrictStr = Field(alias="ownerId")
    seen_at: Optional[datetime] = Field(alias="seenAt")
    show_at: Optional[datetime] = Field(alias="showAt")
    type: MemoryType
    updated_at: datetime = Field(alias="updatedAt")
    __properties: ClassVar[List[str]] = [
        "createdAt",
        "data",
        "deletedAt",
        "hideAt",
        "id",
        "isSaved",
        "memoryAt",
        "ownerId",
        "seenAt",
        "showAt",
        "type",
        "updatedAt",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyncMemoryV1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if deleted_at (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_at is None and "deleted_at" in self.model_fields_set:
            _dict["deletedAt"] = None

        # set to None if hide_at (nullable) is None
        # and model_fields_set contains the field
        if self.hide_at is None and "hide_at" in self.model_fields_set:
            _dict["hideAt"] = None

        # set to None if seen_at (nullable) is None
        # and model_fields_set contains the field
        if self.seen_at is None and "seen_at" in self.model_fields_set:
            _dict["seenAt"] = None

        # set to None if show_at (nullable) is None
        # and model_fields_set contains the field
        if self.show_at is None and "show_at" in self.model_fields_set:
            _dict["showAt"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyncMemoryV1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "createdAt": obj.get("createdAt"),
                "data": obj.get("data"),
                "deletedAt": obj.get("deletedAt"),
                "hideAt": obj.get("hideAt"),
                "id": obj.get("id"),
                "isSaved": obj.get("isSaved"),
                "memoryAt": obj.get("memoryAt"),
                "ownerId": obj.get("ownerId"),
                "seenAt": obj.get("seenAt"),
                "showAt": obj.get("showAt"),
                "type": obj.get("type"),
                "updatedAt": obj.get("updatedAt"),
            }
        )
        return _obj
