# flake8: noqa

# import apis into api package
from immich.client.api.api_keys_api import APIKeysApi
from immich.client.api.activities_api import ActivitiesApi
from immich.client.api.albums_api import AlbumsApi
from immich.client.api.assets_api import AssetsApi
from immich.client.api.authentication_api import AuthenticationApi
from immich.client.api.authentication_admin_api import AuthenticationAdminApi
from immich.client.api.deprecated_api import DeprecatedApi
from immich.client.api.download_api import DownloadApi
from immich.client.api.duplicates_api import DuplicatesApi
from immich.client.api.faces_api import FacesApi
from immich.client.api.jobs_api import JobsApi
from immich.client.api.libraries_api import LibrariesApi
from immich.client.api.maintenance_admin_api import MaintenanceAdminApi
from immich.client.api.map_api import MapApi
from immich.client.api.memories_api import MemoriesApi
from immich.client.api.notifications_api import NotificationsApi
from immich.client.api.notifications_admin_api import NotificationsAdminApi
from immich.client.api.partners_api import PartnersApi
from immich.client.api.people_api import PeopleApi
from immich.client.api.plugins_api import PluginsApi
from immich.client.api.queues_api import QueuesApi
from immich.client.api.search_api import SearchApi
from immich.client.api.server_api import ServerApi
from immich.client.api.sessions_api import SessionsApi
from immich.client.api.shared_links_api import SharedLinksApi
from immich.client.api.stacks_api import StacksApi
from immich.client.api.sync_api import SyncApi
from immich.client.api.system_config_api import SystemConfigApi
from immich.client.api.system_metadata_api import SystemMetadataApi
from immich.client.api.tags_api import TagsApi
from immich.client.api.timeline_api import TimelineApi
from immich.client.api.trash_api import TrashApi
from immich.client.api.users_api import UsersApi
from immich.client.api.users_admin_api import UsersAdminApi
from immich.client.api.views_api import ViewsApi
from immich.client.api.workflows_api import WorkflowsApi
