# coding: utf-8

# flake8: noqa
"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from immich.client.models.api_key_create_dto import APIKeyCreateDto
from immich.client.models.api_key_create_response_dto import APIKeyCreateResponseDto
from immich.client.models.api_key_response_dto import APIKeyResponseDto
from immich.client.models.api_key_update_dto import APIKeyUpdateDto
from immich.client.models.activity_create_dto import ActivityCreateDto
from immich.client.models.activity_response_dto import ActivityResponseDto
from immich.client.models.activity_statistics_response_dto import (
    ActivityStatisticsResponseDto,
)
from immich.client.models.add_users_dto import AddUsersDto
from immich.client.models.admin_onboarding_update_dto import AdminOnboardingUpdateDto
from immich.client.models.album_response_dto import AlbumResponseDto
from immich.client.models.album_statistics_response_dto import (
    AlbumStatisticsResponseDto,
)
from immich.client.models.album_user_add_dto import AlbumUserAddDto
from immich.client.models.album_user_create_dto import AlbumUserCreateDto
from immich.client.models.album_user_response_dto import AlbumUserResponseDto
from immich.client.models.album_user_role import AlbumUserRole
from immich.client.models.albums_add_assets_dto import AlbumsAddAssetsDto
from immich.client.models.albums_add_assets_response_dto import (
    AlbumsAddAssetsResponseDto,
)
from immich.client.models.albums_response import AlbumsResponse
from immich.client.models.albums_update import AlbumsUpdate
from immich.client.models.asset_bulk_delete_dto import AssetBulkDeleteDto
from immich.client.models.asset_bulk_update_dto import AssetBulkUpdateDto
from immich.client.models.asset_bulk_upload_check_dto import AssetBulkUploadCheckDto
from immich.client.models.asset_bulk_upload_check_item import AssetBulkUploadCheckItem
from immich.client.models.asset_bulk_upload_check_response_dto import (
    AssetBulkUploadCheckResponseDto,
)
from immich.client.models.asset_bulk_upload_check_result import (
    AssetBulkUploadCheckResult,
)
from immich.client.models.asset_copy_dto import AssetCopyDto
from immich.client.models.asset_delta_sync_dto import AssetDeltaSyncDto
from immich.client.models.asset_delta_sync_response_dto import AssetDeltaSyncResponseDto
from immich.client.models.asset_face_create_dto import AssetFaceCreateDto
from immich.client.models.asset_face_delete_dto import AssetFaceDeleteDto
from immich.client.models.asset_face_response_dto import AssetFaceResponseDto
from immich.client.models.asset_face_update_dto import AssetFaceUpdateDto
from immich.client.models.asset_face_update_item import AssetFaceUpdateItem
from immich.client.models.asset_face_without_person_response_dto import (
    AssetFaceWithoutPersonResponseDto,
)
from immich.client.models.asset_full_sync_dto import AssetFullSyncDto
from immich.client.models.asset_ids_dto import AssetIdsDto
from immich.client.models.asset_ids_response_dto import AssetIdsResponseDto
from immich.client.models.asset_job_name import AssetJobName
from immich.client.models.asset_jobs_dto import AssetJobsDto
from immich.client.models.asset_media_response_dto import AssetMediaResponseDto
from immich.client.models.asset_media_size import AssetMediaSize
from immich.client.models.asset_media_status import AssetMediaStatus
from immich.client.models.asset_metadata_key import AssetMetadataKey
from immich.client.models.asset_metadata_response_dto import AssetMetadataResponseDto
from immich.client.models.asset_metadata_upsert_dto import AssetMetadataUpsertDto
from immich.client.models.asset_metadata_upsert_item_dto import (
    AssetMetadataUpsertItemDto,
)
from immich.client.models.asset_ocr_response_dto import AssetOcrResponseDto
from immich.client.models.asset_order import AssetOrder
from immich.client.models.asset_response_dto import AssetResponseDto
from immich.client.models.asset_stack_response_dto import AssetStackResponseDto
from immich.client.models.asset_stats_response_dto import AssetStatsResponseDto
from immich.client.models.asset_type_enum import AssetTypeEnum
from immich.client.models.asset_visibility import AssetVisibility
from immich.client.models.audio_codec import AudioCodec
from immich.client.models.auth_status_response_dto import AuthStatusResponseDto
from immich.client.models.avatar_update import AvatarUpdate
from immich.client.models.bulk_id_error_reason import BulkIdErrorReason
from immich.client.models.bulk_id_response_dto import BulkIdResponseDto
from immich.client.models.bulk_ids_dto import BulkIdsDto
from immich.client.models.clip_config import CLIPConfig
from immich.client.models.cq_mode import CQMode
from immich.client.models.cast_response import CastResponse
from immich.client.models.cast_update import CastUpdate
from immich.client.models.change_password_dto import ChangePasswordDto
from immich.client.models.check_existing_assets_dto import CheckExistingAssetsDto
from immich.client.models.check_existing_assets_response_dto import (
    CheckExistingAssetsResponseDto,
)
from immich.client.models.colorspace import Colorspace
from immich.client.models.contributor_count_response_dto import (
    ContributorCountResponseDto,
)
from immich.client.models.create_album_dto import CreateAlbumDto
from immich.client.models.create_library_dto import CreateLibraryDto
from immich.client.models.create_profile_image_response_dto import (
    CreateProfileImageResponseDto,
)
from immich.client.models.database_backup_config import DatabaseBackupConfig
from immich.client.models.download_archive_info import DownloadArchiveInfo
from immich.client.models.download_info_dto import DownloadInfoDto
from immich.client.models.download_response import DownloadResponse
from immich.client.models.download_response_dto import DownloadResponseDto
from immich.client.models.download_update import DownloadUpdate
from immich.client.models.duplicate_detection_config import DuplicateDetectionConfig
from immich.client.models.duplicate_response_dto import DuplicateResponseDto
from immich.client.models.email_notifications_response import EmailNotificationsResponse
from immich.client.models.email_notifications_update import EmailNotificationsUpdate
from immich.client.models.exif_response_dto import ExifResponseDto
from immich.client.models.face_dto import FaceDto
from immich.client.models.facial_recognition_config import FacialRecognitionConfig
from immich.client.models.folders_response import FoldersResponse
from immich.client.models.folders_update import FoldersUpdate
from immich.client.models.image_format import ImageFormat
from immich.client.models.job_create_dto import JobCreateDto
from immich.client.models.job_name import JobName
from immich.client.models.job_settings_dto import JobSettingsDto
from immich.client.models.library_response_dto import LibraryResponseDto
from immich.client.models.library_stats_response_dto import LibraryStatsResponseDto
from immich.client.models.license_key_dto import LicenseKeyDto
from immich.client.models.license_response_dto import LicenseResponseDto
from immich.client.models.log_level import LogLevel
from immich.client.models.login_credential_dto import LoginCredentialDto
from immich.client.models.login_response_dto import LoginResponseDto
from immich.client.models.logout_response_dto import LogoutResponseDto
from immich.client.models.machine_learning_availability_checks_dto import (
    MachineLearningAvailabilityChecksDto,
)
from immich.client.models.maintenance_action import MaintenanceAction
from immich.client.models.maintenance_auth_dto import MaintenanceAuthDto
from immich.client.models.maintenance_login_dto import MaintenanceLoginDto
from immich.client.models.manual_job_name import ManualJobName
from immich.client.models.map_marker_response_dto import MapMarkerResponseDto
from immich.client.models.map_reverse_geocode_response_dto import (
    MapReverseGeocodeResponseDto,
)
from immich.client.models.memories_response import MemoriesResponse
from immich.client.models.memories_update import MemoriesUpdate
from immich.client.models.memory_create_dto import MemoryCreateDto
from immich.client.models.memory_response_dto import MemoryResponseDto
from immich.client.models.memory_search_order import MemorySearchOrder
from immich.client.models.memory_statistics_response_dto import (
    MemoryStatisticsResponseDto,
)
from immich.client.models.memory_type import MemoryType
from immich.client.models.memory_update_dto import MemoryUpdateDto
from immich.client.models.merge_person_dto import MergePersonDto
from immich.client.models.metadata_search_dto import MetadataSearchDto
from immich.client.models.notification_create_dto import NotificationCreateDto
from immich.client.models.notification_delete_all_dto import NotificationDeleteAllDto
from immich.client.models.notification_dto import NotificationDto
from immich.client.models.notification_level import NotificationLevel
from immich.client.models.notification_type import NotificationType
from immich.client.models.notification_update_all_dto import NotificationUpdateAllDto
from immich.client.models.notification_update_dto import NotificationUpdateDto
from immich.client.models.o_auth_authorize_response_dto import OAuthAuthorizeResponseDto
from immich.client.models.o_auth_callback_dto import OAuthCallbackDto
from immich.client.models.o_auth_config_dto import OAuthConfigDto
from immich.client.models.o_auth_token_endpoint_auth_method import (
    OAuthTokenEndpointAuthMethod,
)
from immich.client.models.ocr_config import OcrConfig
from immich.client.models.on_this_day_dto import OnThisDayDto
from immich.client.models.onboarding_dto import OnboardingDto
from immich.client.models.onboarding_response_dto import OnboardingResponseDto
from immich.client.models.partner_create_dto import PartnerCreateDto
from immich.client.models.partner_direction import PartnerDirection
from immich.client.models.partner_response_dto import PartnerResponseDto
from immich.client.models.partner_update_dto import PartnerUpdateDto
from immich.client.models.people_response import PeopleResponse
from immich.client.models.people_response_dto import PeopleResponseDto
from immich.client.models.people_update import PeopleUpdate
from immich.client.models.people_update_dto import PeopleUpdateDto
from immich.client.models.people_update_item import PeopleUpdateItem
from immich.client.models.permission import Permission
from immich.client.models.person_create_dto import PersonCreateDto
from immich.client.models.person_response_dto import PersonResponseDto
from immich.client.models.person_statistics_response_dto import (
    PersonStatisticsResponseDto,
)
from immich.client.models.person_update_dto import PersonUpdateDto
from immich.client.models.person_with_faces_response_dto import (
    PersonWithFacesResponseDto,
)
from immich.client.models.pin_code_change_dto import PinCodeChangeDto
from immich.client.models.pin_code_reset_dto import PinCodeResetDto
from immich.client.models.pin_code_setup_dto import PinCodeSetupDto
from immich.client.models.places_response_dto import PlacesResponseDto
from immich.client.models.plugin_action_response_dto import PluginActionResponseDto
from immich.client.models.plugin_context_type import PluginContextType
from immich.client.models.plugin_filter_response_dto import PluginFilterResponseDto
from immich.client.models.plugin_response_dto import PluginResponseDto
from immich.client.models.plugin_trigger_response_dto import PluginTriggerResponseDto
from immich.client.models.plugin_trigger_type import PluginTriggerType
from immich.client.models.purchase_response import PurchaseResponse
from immich.client.models.purchase_update import PurchaseUpdate
from immich.client.models.queue_command import QueueCommand
from immich.client.models.queue_command_dto import QueueCommandDto
from immich.client.models.queue_delete_dto import QueueDeleteDto
from immich.client.models.queue_job_response_dto import QueueJobResponseDto
from immich.client.models.queue_job_status import QueueJobStatus
from immich.client.models.queue_name import QueueName
from immich.client.models.queue_response_dto import QueueResponseDto
from immich.client.models.queue_response_legacy_dto import QueueResponseLegacyDto
from immich.client.models.queue_statistics_dto import QueueStatisticsDto
from immich.client.models.queue_status_legacy_dto import QueueStatusLegacyDto
from immich.client.models.queue_update_dto import QueueUpdateDto
from immich.client.models.queues_response_legacy_dto import QueuesResponseLegacyDto
from immich.client.models.random_search_dto import RandomSearchDto
from immich.client.models.ratings_response import RatingsResponse
from immich.client.models.ratings_update import RatingsUpdate
from immich.client.models.reaction_level import ReactionLevel
from immich.client.models.reaction_type import ReactionType
from immich.client.models.reverse_geocoding_state_response_dto import (
    ReverseGeocodingStateResponseDto,
)
from immich.client.models.search_album_response_dto import SearchAlbumResponseDto
from immich.client.models.search_asset_response_dto import SearchAssetResponseDto
from immich.client.models.search_explore_item import SearchExploreItem
from immich.client.models.search_explore_response_dto import SearchExploreResponseDto
from immich.client.models.search_facet_count_response_dto import (
    SearchFacetCountResponseDto,
)
from immich.client.models.search_facet_response_dto import SearchFacetResponseDto
from immich.client.models.search_response_dto import SearchResponseDto
from immich.client.models.search_statistics_response_dto import (
    SearchStatisticsResponseDto,
)
from immich.client.models.search_suggestion_type import SearchSuggestionType
from immich.client.models.server_about_response_dto import ServerAboutResponseDto
from immich.client.models.server_apk_links_dto import ServerApkLinksDto
from immich.client.models.server_config_dto import ServerConfigDto
from immich.client.models.server_features_dto import ServerFeaturesDto
from immich.client.models.server_media_types_response_dto import (
    ServerMediaTypesResponseDto,
)
from immich.client.models.server_ping_response import ServerPingResponse
from immich.client.models.server_stats_response_dto import ServerStatsResponseDto
from immich.client.models.server_storage_response_dto import ServerStorageResponseDto
from immich.client.models.server_theme_dto import ServerThemeDto
from immich.client.models.server_version_history_response_dto import (
    ServerVersionHistoryResponseDto,
)
from immich.client.models.server_version_response_dto import ServerVersionResponseDto
from immich.client.models.session_create_dto import SessionCreateDto
from immich.client.models.session_create_response_dto import SessionCreateResponseDto
from immich.client.models.session_response_dto import SessionResponseDto
from immich.client.models.session_unlock_dto import SessionUnlockDto
from immich.client.models.session_update_dto import SessionUpdateDto
from immich.client.models.set_maintenance_mode_dto import SetMaintenanceModeDto
from immich.client.models.shared_link_create_dto import SharedLinkCreateDto
from immich.client.models.shared_link_edit_dto import SharedLinkEditDto
from immich.client.models.shared_link_response_dto import SharedLinkResponseDto
from immich.client.models.shared_link_type import SharedLinkType
from immich.client.models.shared_links_response import SharedLinksResponse
from immich.client.models.shared_links_update import SharedLinksUpdate
from immich.client.models.sign_up_dto import SignUpDto
from immich.client.models.smart_search_dto import SmartSearchDto
from immich.client.models.source_type import SourceType
from immich.client.models.stack_create_dto import StackCreateDto
from immich.client.models.stack_response_dto import StackResponseDto
from immich.client.models.stack_update_dto import StackUpdateDto
from immich.client.models.statistics_search_dto import StatisticsSearchDto
from immich.client.models.sync_ack_delete_dto import SyncAckDeleteDto
from immich.client.models.sync_ack_dto import SyncAckDto
from immich.client.models.sync_ack_set_dto import SyncAckSetDto
from immich.client.models.sync_album_delete_v1 import SyncAlbumDeleteV1
from immich.client.models.sync_album_to_asset_delete_v1 import SyncAlbumToAssetDeleteV1
from immich.client.models.sync_album_to_asset_v1 import SyncAlbumToAssetV1
from immich.client.models.sync_album_user_delete_v1 import SyncAlbumUserDeleteV1
from immich.client.models.sync_album_user_v1 import SyncAlbumUserV1
from immich.client.models.sync_album_v1 import SyncAlbumV1
from immich.client.models.sync_asset_delete_v1 import SyncAssetDeleteV1
from immich.client.models.sync_asset_exif_v1 import SyncAssetExifV1
from immich.client.models.sync_asset_face_delete_v1 import SyncAssetFaceDeleteV1
from immich.client.models.sync_asset_face_v1 import SyncAssetFaceV1
from immich.client.models.sync_asset_metadata_delete_v1 import SyncAssetMetadataDeleteV1
from immich.client.models.sync_asset_metadata_v1 import SyncAssetMetadataV1
from immich.client.models.sync_asset_v1 import SyncAssetV1
from immich.client.models.sync_auth_user_v1 import SyncAuthUserV1
from immich.client.models.sync_entity_type import SyncEntityType
from immich.client.models.sync_memory_asset_delete_v1 import SyncMemoryAssetDeleteV1
from immich.client.models.sync_memory_asset_v1 import SyncMemoryAssetV1
from immich.client.models.sync_memory_delete_v1 import SyncMemoryDeleteV1
from immich.client.models.sync_memory_v1 import SyncMemoryV1
from immich.client.models.sync_partner_delete_v1 import SyncPartnerDeleteV1
from immich.client.models.sync_partner_v1 import SyncPartnerV1
from immich.client.models.sync_person_delete_v1 import SyncPersonDeleteV1
from immich.client.models.sync_person_v1 import SyncPersonV1
from immich.client.models.sync_request_type import SyncRequestType
from immich.client.models.sync_stack_delete_v1 import SyncStackDeleteV1
from immich.client.models.sync_stack_v1 import SyncStackV1
from immich.client.models.sync_stream_dto import SyncStreamDto
from immich.client.models.sync_user_delete_v1 import SyncUserDeleteV1
from immich.client.models.sync_user_metadata_delete_v1 import SyncUserMetadataDeleteV1
from immich.client.models.sync_user_metadata_v1 import SyncUserMetadataV1
from immich.client.models.sync_user_v1 import SyncUserV1
from immich.client.models.system_config_backups_dto import SystemConfigBackupsDto
from immich.client.models.system_config_dto import SystemConfigDto
from immich.client.models.system_config_f_fmpeg_dto import SystemConfigFFmpegDto
from immich.client.models.system_config_faces_dto import SystemConfigFacesDto
from immich.client.models.system_config_generated_fullsize_image_dto import (
    SystemConfigGeneratedFullsizeImageDto,
)
from immich.client.models.system_config_generated_image_dto import (
    SystemConfigGeneratedImageDto,
)
from immich.client.models.system_config_image_dto import SystemConfigImageDto
from immich.client.models.system_config_job_dto import SystemConfigJobDto
from immich.client.models.system_config_library_dto import SystemConfigLibraryDto
from immich.client.models.system_config_library_scan_dto import (
    SystemConfigLibraryScanDto,
)
from immich.client.models.system_config_library_watch_dto import (
    SystemConfigLibraryWatchDto,
)
from immich.client.models.system_config_logging_dto import SystemConfigLoggingDto
from immich.client.models.system_config_machine_learning_dto import (
    SystemConfigMachineLearningDto,
)
from immich.client.models.system_config_map_dto import SystemConfigMapDto
from immich.client.models.system_config_metadata_dto import SystemConfigMetadataDto
from immich.client.models.system_config_new_version_check_dto import (
    SystemConfigNewVersionCheckDto,
)
from immich.client.models.system_config_nightly_tasks_dto import (
    SystemConfigNightlyTasksDto,
)
from immich.client.models.system_config_notifications_dto import (
    SystemConfigNotificationsDto,
)
from immich.client.models.system_config_o_auth_dto import SystemConfigOAuthDto
from immich.client.models.system_config_password_login_dto import (
    SystemConfigPasswordLoginDto,
)
from immich.client.models.system_config_reverse_geocoding_dto import (
    SystemConfigReverseGeocodingDto,
)
from immich.client.models.system_config_server_dto import SystemConfigServerDto
from immich.client.models.system_config_smtp_dto import SystemConfigSmtpDto
from immich.client.models.system_config_smtp_transport_dto import (
    SystemConfigSmtpTransportDto,
)
from immich.client.models.system_config_storage_template_dto import (
    SystemConfigStorageTemplateDto,
)
from immich.client.models.system_config_template_emails_dto import (
    SystemConfigTemplateEmailsDto,
)
from immich.client.models.system_config_template_storage_option_dto import (
    SystemConfigTemplateStorageOptionDto,
)
from immich.client.models.system_config_templates_dto import SystemConfigTemplatesDto
from immich.client.models.system_config_theme_dto import SystemConfigThemeDto
from immich.client.models.system_config_trash_dto import SystemConfigTrashDto
from immich.client.models.system_config_user_dto import SystemConfigUserDto
from immich.client.models.tag_bulk_assets_dto import TagBulkAssetsDto
from immich.client.models.tag_bulk_assets_response_dto import TagBulkAssetsResponseDto
from immich.client.models.tag_create_dto import TagCreateDto
from immich.client.models.tag_response_dto import TagResponseDto
from immich.client.models.tag_update_dto import TagUpdateDto
from immich.client.models.tag_upsert_dto import TagUpsertDto
from immich.client.models.tags_response import TagsResponse
from immich.client.models.tags_update import TagsUpdate
from immich.client.models.template_dto import TemplateDto
from immich.client.models.template_response_dto import TemplateResponseDto
from immich.client.models.test_email_response_dto import TestEmailResponseDto
from immich.client.models.time_bucket_asset_response_dto import (
    TimeBucketAssetResponseDto,
)
from immich.client.models.time_buckets_response_dto import TimeBucketsResponseDto
from immich.client.models.tone_mapping import ToneMapping
from immich.client.models.transcode_hw_accel import TranscodeHWAccel
from immich.client.models.transcode_policy import TranscodePolicy
from immich.client.models.trash_response_dto import TrashResponseDto
from immich.client.models.update_album_dto import UpdateAlbumDto
from immich.client.models.update_album_user_dto import UpdateAlbumUserDto
from immich.client.models.update_asset_dto import UpdateAssetDto
from immich.client.models.update_library_dto import UpdateLibraryDto
from immich.client.models.usage_by_user_dto import UsageByUserDto
from immich.client.models.user_admin_create_dto import UserAdminCreateDto
from immich.client.models.user_admin_delete_dto import UserAdminDeleteDto
from immich.client.models.user_admin_response_dto import UserAdminResponseDto
from immich.client.models.user_admin_update_dto import UserAdminUpdateDto
from immich.client.models.user_avatar_color import UserAvatarColor
from immich.client.models.user_license import UserLicense
from immich.client.models.user_metadata_key import UserMetadataKey
from immich.client.models.user_preferences_response_dto import (
    UserPreferencesResponseDto,
)
from immich.client.models.user_preferences_update_dto import UserPreferencesUpdateDto
from immich.client.models.user_response_dto import UserResponseDto
from immich.client.models.user_status import UserStatus
from immich.client.models.user_update_me_dto import UserUpdateMeDto
from immich.client.models.validate_access_token_response_dto import (
    ValidateAccessTokenResponseDto,
)
from immich.client.models.validate_library_dto import ValidateLibraryDto
from immich.client.models.validate_library_import_path_response_dto import (
    ValidateLibraryImportPathResponseDto,
)
from immich.client.models.validate_library_response_dto import (
    ValidateLibraryResponseDto,
)
from immich.client.models.version_check_state_response_dto import (
    VersionCheckStateResponseDto,
)
from immich.client.models.video_codec import VideoCodec
from immich.client.models.video_container import VideoContainer
from immich.client.models.workflow_action_item_dto import WorkflowActionItemDto
from immich.client.models.workflow_action_response_dto import WorkflowActionResponseDto
from immich.client.models.workflow_create_dto import WorkflowCreateDto
from immich.client.models.workflow_filter_item_dto import WorkflowFilterItemDto
from immich.client.models.workflow_filter_response_dto import WorkflowFilterResponseDto
from immich.client.models.workflow_response_dto import WorkflowResponseDto
from immich.client.models.workflow_update_dto import WorkflowUpdateDto
