# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from uuid import UUID
from immich.client.models.asset_visibility import AssetVisibility
from typing import Set
from typing_extensions import Self


class UpdateAssetDto(BaseModel):
    """
    UpdateAssetDto
    """  # noqa: E501

    date_time_original: Optional[StrictStr] = Field(
        default=None, alias="dateTimeOriginal"
    )
    description: Optional[StrictStr] = None
    is_favorite: Optional[StrictBool] = Field(default=None, alias="isFavorite")
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    live_photo_video_id: Optional[UUID] = Field(default=None, alias="livePhotoVideoId")
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    rating: Optional[
        Union[
            Annotated[float, Field(le=5, strict=True, ge=-1)],
            Annotated[int, Field(le=5, strict=True, ge=-1)],
        ]
    ] = None
    visibility: Optional[AssetVisibility] = None
    __properties: ClassVar[List[str]] = [
        "dateTimeOriginal",
        "description",
        "isFavorite",
        "latitude",
        "livePhotoVideoId",
        "longitude",
        "rating",
        "visibility",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateAssetDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if live_photo_video_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.live_photo_video_id is None
            and "live_photo_video_id" in self.model_fields_set
        ):
            _dict["livePhotoVideoId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateAssetDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "dateTimeOriginal": obj.get("dateTimeOriginal"),
                "description": obj.get("description"),
                "isFavorite": obj.get("isFavorite"),
                "latitude": obj.get("latitude"),
                "livePhotoVideoId": obj.get("livePhotoVideoId"),
                "longitude": obj.get("longitude"),
                "rating": obj.get("rating"),
                "visibility": obj.get("visibility"),
            }
        )
        return _obj
