# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.plugin_context_type import PluginContextType
from typing import Set
from typing_extensions import Self


class PluginFilterResponseDto(BaseModel):
    """
    PluginFilterResponseDto
    """  # noqa: E501

    description: StrictStr
    id: StrictStr
    method_name: StrictStr = Field(alias="methodName")
    plugin_id: StrictStr = Field(alias="pluginId")
    var_schema: Optional[Dict[str, Any]] = Field(alias="schema")
    supported_contexts: List[PluginContextType] = Field(alias="supportedContexts")
    title: StrictStr
    __properties: ClassVar[List[str]] = [
        "description",
        "id",
        "methodName",
        "pluginId",
        "schema",
        "supportedContexts",
        "title",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PluginFilterResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if var_schema (nullable) is None
        # and model_fields_set contains the field
        if self.var_schema is None and "var_schema" in self.model_fields_set:
            _dict["schema"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PluginFilterResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "description": obj.get("description"),
                "id": obj.get("id"),
                "methodName": obj.get("methodName"),
                "pluginId": obj.get("pluginId"),
                "schema": obj.get("schema"),
                "supportedContexts": obj.get("supportedContexts"),
                "title": obj.get("title"),
            }
        )
        return _obj
