# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AssetJobName(str, Enum):
    """
    AssetJobName
    """

    """
    allowed enum values
    """
    REFRESH_MINUS_FACES = "refresh-faces"
    REFRESH_MINUS_METADATA = "refresh-metadata"
    REGENERATE_MINUS_THUMBNAIL = "regenerate-thumbnail"
    TRANSCODE_MINUS_VIDEO = "transcode-video"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AssetJobName from a JSON string"""
        return cls(json.loads(json_str))
