# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class SessionCreateResponseDto(BaseModel):
    """
    SessionCreateResponseDto
    """  # noqa: E501

    app_version: Optional[StrictStr] = Field(alias="appVersion")
    created_at: StrictStr = Field(alias="createdAt")
    current: StrictBool
    device_os: StrictStr = Field(alias="deviceOS")
    device_type: StrictStr = Field(alias="deviceType")
    expires_at: Optional[StrictStr] = Field(default=None, alias="expiresAt")
    id: StrictStr
    is_pending_sync_reset: StrictBool = Field(alias="isPendingSyncReset")
    token: StrictStr
    updated_at: StrictStr = Field(alias="updatedAt")
    __properties: ClassVar[List[str]] = [
        "appVersion",
        "createdAt",
        "current",
        "deviceOS",
        "deviceType",
        "expiresAt",
        "id",
        "isPendingSyncReset",
        "token",
        "updatedAt",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SessionCreateResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if app_version (nullable) is None
        # and model_fields_set contains the field
        if self.app_version is None and "app_version" in self.model_fields_set:
            _dict["appVersion"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SessionCreateResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "appVersion": obj.get("appVersion"),
                "createdAt": obj.get("createdAt"),
                "current": obj.get("current"),
                "deviceOS": obj.get("deviceOS"),
                "deviceType": obj.get("deviceType"),
                "expiresAt": obj.get("expiresAt"),
                "id": obj.get("id"),
                "isPendingSyncReset": obj.get("isPendingSyncReset"),
                "token": obj.get("token"),
                "updatedAt": obj.get("updatedAt"),
            }
        )
        return _obj
