# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ManualJobName(str, Enum):
    """
    ManualJobName
    """

    """
    allowed enum values
    """
    PERSON_MINUS_CLEANUP = "person-cleanup"
    TAG_MINUS_CLEANUP = "tag-cleanup"
    USER_MINUS_CLEANUP = "user-cleanup"
    MEMORY_MINUS_CLEANUP = "memory-cleanup"
    MEMORY_MINUS_CREATE = "memory-create"
    BACKUP_MINUS_DATABASE = "backup-database"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ManualJobName from a JSON string"""
        return cls(json.loads(json_str))
