# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SyncRequestType(str, Enum):
    """
    SyncRequestType
    """

    """
    allowed enum values
    """
    ALBUMSV1 = "AlbumsV1"
    ALBUMUSERSV1 = "AlbumUsersV1"
    ALBUMTOASSETSV1 = "AlbumToAssetsV1"
    ALBUMASSETSV1 = "AlbumAssetsV1"
    ALBUMASSETEXIFSV1 = "AlbumAssetExifsV1"
    ASSETSV1 = "AssetsV1"
    ASSETEXIFSV1 = "AssetExifsV1"
    ASSETMETADATAV1 = "AssetMetadataV1"
    AUTHUSERSV1 = "AuthUsersV1"
    MEMORIESV1 = "MemoriesV1"
    MEMORYTOASSETSV1 = "MemoryToAssetsV1"
    PARTNERSV1 = "PartnersV1"
    PARTNERASSETSV1 = "PartnerAssetsV1"
    PARTNERASSETEXIFSV1 = "PartnerAssetExifsV1"
    PARTNERSTACKSV1 = "PartnerStacksV1"
    STACKSV1 = "StacksV1"
    USERSV1 = "UsersV1"
    PEOPLEV1 = "PeopleV1"
    ASSETFACESV1 = "AssetFacesV1"
    USERMETADATAV1 = "UserMetadataV1"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SyncRequestType from a JSON string"""
        return cls(json.loads(json_str))
